setwd("/Users/julie/Documents/Thesis/Data")
cons <- read.csv(file="beetrials.csv", na.strings='', header=T)
str(cons)
cons <- cons[1:199,]

# read in wings data
size <- read.csv(file="wings.csv", na.strings = (''), header=T)
size$bee.id<- as.factor(size$bee.id)
is.numeric(size$mm)
is.factor(size$bee.id)

### merge size data and main data frame ###
cons2 <- merge (cons, size, by=c("bee.id"))
str(cons2)

# select complete cases
cons2 <- cons2[complete.cases(cons2$mm), ] 
cons2 <- cons2[complete.cases(cons2$pol.cons), ] 
cons2 <- cons2[complete.cases(cons2$nec.cons), ] 
cons2 <- cons2[complete.cases(cons2$necwt2),]
cons2 <- cons2[complete.cases(cons2$polwt2),]

# remove negative consumptino value
cons2 <- cons2[-c(11), ]



#### Data Visualization ####
cons2$Groups <-as.factor(paste(cons2$amf,cons2$fert))
par(mfrow=c(1,1),mar=c(5,3,1,1),mgp=c(2,0.75,0))
#conditional boxpolot
plot(pol.cons~Groups, cons2, ylim=c(0,.25), pch=21, cex=1, cex.axis=0.75, ylab="Pollen consumption")

plot(nec.cons~Groups, cons2, ylim=c(0,2.3), pch=21, cex=1, cex.axis=0.75, ylab="Nectar consumption")


#histogram
hist(cons2$nec.cons, breaks=seq(0,2.5,.04), cex.axis=.001, xlab="Nectar consumption", main="")
hist(cons2$pol.cons, breaks=seq(0,.5,.001), cex.axis=100, xlab="pollen consumption", main="")


# were there differences in pollen consumption across diets? [including control]
shapiro.test(cons2$nec.cons)
shapiro.test(cons2$pol.cons)


cons2$log.pol <- log(cons2$pol.cons)
cons2$log.nec <- log(cons2$nec.con)


p0 <- lm(log.pol~treat.x+mm+colony+inoc.date.x+log.nec,data=cons2)
p1 <- lm(log.pol~treat.x+mm+colony+inoc.date.x,data=cons2)
p2 <- lm(log.pol~treat.x*mm+colony,data=cons2)
p3 <- lm(log.pol~treat.x+mm*colony,data=cons2)
p4 <- lm(log.pol~treat.x+mm,data=cons2)
p5 <- lm(log.pol~treat.x+colony,data=cons2)
p6 <- lm(log.pol~mm+colony,data=cons2)
p7 <- lm(log.pol~mm,data=cons2)
p8 <- lm(log.pol~colony,data=cons2)
p9 <- lm(log.pol~treat.x,data=cons2)

AIC(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9)
summary(p1)
hist(resid(p1))

# compare to null
p1.null <- lm(log.pol~mm+colony+inoc.date.x,data=cons2)
anova(p1.null, p1, test="F")
# diet treatment did not affect pollen consumption (p=0.09)



##

# test for interaction excluding control diet 

nocont <-  subset(cons2, treat.x != "C")

levels(nocont$treat.x)
nocont$treat.x<-factor(nocont$treat.x)
nocont$amf<-factor(nocont$amf)
nocont$fert<-factor(nocont$fert)


p10 <- lm(log.pol~amf*fert+mm+colony+inoc.date.x+log.nec,data=nocont)
p11 <- lm(log.pol~amf+fert+mm+colony+inoc.date.x+log.nec,data=nocont)
p12 <- lm(log.pol~amf*fert+mm+colony+inoc.date.x,data=nocont)
p13 <- lm(log.pol~amf*fert+mm+log.nec,data=nocont)
p14 <- lm(log.pol~amf+fert+mm+log.nec,data=nocont)
p15 <- lm(log.pol~amf+fert+colony,data=nocont)
p16 <- lm(log.pol~mm+colony,data=nocont)
p17 <- lm(log.pol~mm,data=nocont)
p18 <- lm(log.pol~colony,data=nocont)
p19 <- lm(log.pol~amf*fert,data=nocont)
p20 <- lm(log.pol~fert+inoc.date.x+log.nec,data=nocont)
p21 <- lm(log.pol~amf+inoc.date.x+log.nec,data=nocont)

AIC(p10,p11,p12,p13,p14,p15,p16,p17,p18,p19, p20,p21)
summary(p20)
hist(resid(p20))


plot(p20)

## build null model
p20.null <- lm(log.pol~inoc.date.x+log.nec,data=nocont)
anova(p20.null, p20, test = "F")

p20.nonec <- lm(log.pol~fert+inoc.date.x,data=nocont)
anova(p20.nonec, p20, test = "F")

library(car
        )

vif(p20)



# no effect of treatment on pollen consumption
# x2 = p = 0.149, 



# were there differences in nectar consumption across AMF treatments?????
# test including control diet

n0 <- lm(log.nec~treat.x+mm+colony+inoc.date.x+log.pol,data=cons2)
n1 <- lm(log.nec~treat.x+mm+colony+inoc.date.x,data=cons2)
n2 <- lm(log.nec~treat.x*mm+colony,data=cons2)
n3 <- lm(log.nec~treat.x+mm*colony,data=cons2)
n4 <- lm(log.nec~treat.x+mm,data=cons2)
n5 <- lm(log.nec~treat.x+colony,data=cons2)
n6 <- lm(log.nec~mm+colony,data=cons2)
n7 <- lm(log.nec~mm,data=cons2)
n8 <- lm(log.nec~colony,data=cons2)
n9 <- lm(log.nec~treat.x,data=cons2)

AIC(n0,n1,n2,n3,n4,n5,n6,n7,n8,n9)
summary(n5)
hist(resid(n8))
plot(n8)
# compare to null
n8.null <- lm(log.nec~1,data=cons2)
anova(n8.null, n8, test="F")
# just checking, diet treatment did not affect nectar consumption:
anova(n5, n8, test="F")



##

# test for interaction excluding control diet 


n10 <- lm(log.nec~amf*fert+mm+colony+inoc.date.x+log.pol,data=nocont)
n11 <- lm(log.nec~amf+fert+mm+colony+inoc.date.x+log.pol,data=nocont)
n12 <- lm(log.nec~amf*fert+mm+colony+inoc.date.x,data=nocont)
n13 <- lm(log.nec~amf*fert+mm+log.pol,data=nocont)
n14 <- lm(log.nec~amf+fert+mm+log.pol,data=nocont)
n15 <- lm(log.nec~amf+fert+colony,data=nocont)
n16 <- lm(log.nec~mm+colony,data=nocont)
n17 <- lm(log.nec~mm,data=nocont)
n18 <- lm(log.nec~colony,data=nocont)
n19 <- lm(log.nec~amf*fert,data=nocont)
n20 <- lm(log.nec~fert+inoc.date.x+log.pol,data=nocont)
n21 <- lm(log.nec~amf+inoc.date.x+log.pol,data=nocont)

AIC(n10,n11,n12,n13,n14,n15,n16,n17,n18,n19, n20,n21)
summary(n21)
hist(resid(n21))


plot(n21)

## build null models
n21.noamf <- lm(log.nec~inoc.date.x+log.pol,data=nocont)
n21.noinoc <- lm(log.nec~amf+log.pol,data=nocont)
n21.nopol <- lm(log.nec~amf+inoc.date.x,data=nocont)

anova(n21, n21.noamf, test = "F")

anova(n21, n21.noinoc, test = "F")
anova(n21, n21.nopol, test = "F")

library(car
)

vif(n21)

