setwd("/Users/julie/Documents/Thesis/Data")

#read in the data
bees <- read.csv(file="beetrials.csv",header=T)
str(bees)
bees <- bees[1:199,]

### Data manipulation and organization - nothing changed from what Julie originally did ###

bees$bee.id <- as.factor(bees$bee.id) # make bee ID a factor

wings <- read.csv(file="wings.csv", na.strings = (''), header=T)
wings$bee.id<- as.factor(wings$bee.id)
is.numeric(wings$mm)

### merge wing data and main data frame ###
bees<- merge (bees, wings, by=c("bee.id"))


### turn bee size and consumption into z-scores
bees$mm <- scale (bees$mm, center=TRUE, scale=TRUE)
bees$pol.cons.scaled <- scale (bees$pol.cons, center=TRUE, scale=TRUE)
bees$nec.cons.scaled <- scale (bees$nec.cons, center=TRUE, scale=TRUE)

head(bees)


#  'diet' refers to tobacco vs control diet
# 'treat' is specific diet treatment (AH, NH, AL, NL, Control)
# 'fert' is H/L fert diet treatment (excludes control)
# 'amf" is y/n AMF diet treatment (excludes control)


bees$bee.id <- as.factor(bees$bee.id) # make bee ID a factor
# complete cases
bees <- bees[complete.cases(bees$polwt2), ] 
bees <- bees[complete.cases(bees$mm), ] 
bees = bees[bees$pol.cons > 0,]

### we can't use size as a covariate because we dont have size data on early deaths



# set up the response variable
library(survival)
S <-Surv(
  time=bees$days.to.death,
  event=bees$dead.before.dissect
)

#build the model
model3 <- coxph(S~treat.x,data=bees)

#cant test diet treatment - model wont converge likely due to low replication

### let's try testing high vs low fert and AMF+/AMF- separately

#################### High vs low vs control

### set up response variable for high vs low vs control
SFC <-Surv(
  time=bees$days.to.death,
  event=bees$dead.before.dissect
)

#build the model comparing High fert, low fert and control
# note: not enough replication to include fertilizer and inoculation date
# int he same model, or colony and inoculation date in the same model
fertCmodel1 <- coxph(SFC~fert,data=bees) # with fertilizer and control
fertCmodel2 <-coxph(SFC~fert+colony,data=bees) # colony matters
fertCmodel3 <-coxph(SFC~fert+nec.cons+colony,data=bees) # colony matters
fertCmodel4 <-coxph(SFC~nec.cons.scaled,data=bees) # colony matters
fertCmodel5 <-coxph(SFC~fert+colony,data=bees) # colony matters
fertCmodel6 <-coxph(SFC~fert+pol.cons.scaled+nec.cons.scaled,data=bees) # colony matters
fertCmodel7 <-coxph(SFC~fert+pol.cons.scaled+nec.cons.scaled+colony,data=bees) # colony matters
fertCmodel8 <-coxph(SFC~fert+pol.cons.scaled+colony,data=bees) # colony matters
fertCmodel9 <-coxph(SFC~fert+pol.cons.scaled+nec.cons.scaled,data=bees) # colony matters
fertCmodel10 <-coxph(SFC~colony,data=bees) # colony matters

# only models 5, 6, 10 converge. test AIC 
AIC (fertCmodel5, fertCmodel6, fertCmodel10)

# model 5 wins: 
# when I compare H/L fert and control, only colony matters
summary(fertCmodel5)

############## AMF+ vs AMF- vs control

#set up response variable for high vs low vs control
SAC <-Surv(
  time=bees$days.to.death,
  event=bees$dead.before.dissect
)

#build the model comparing AMF, noAMF, and control
amfCmodel <- coxph(SAC~amf,data=bees) # with AMF and control
amfCmodel2 <-coxph(SAC~amf+colony,data=bees) # colony matters
amfCmodel3 <-coxph(SAC~amf+inoc.date.x,data=bees) #can't include inoculation - not enough replication to converge
amfCmodel4 <-coxph(SAC~colony,data=bees) # drop treatment, keep colony
amfCmodel5 <-coxph(SAC~inoc.date.x,data=bees) # drop treatment, keep inoc date
amfCmodel6 <-coxph(SAC~amf+nec.cons.scaled+pol.cons.scaled+colony,data=bees) 
amfCmodel7 <-coxph(SAC~nec.cons.scaled,data=bees) 
amfCmodel8 <-coxph(SAC~pol.cons.scaled,data=bees) 
amfCmodel9 <-coxph(SAC~amf+pol.cons.scaled+colony,data=bees) 
amfCmodel10 <-coxph(SAC~amf+nec.cons.scaled+colony,data=bees) 
amfCmodel11 <-coxph(SAC~nec.cons.scaled+pol.cons.scaled+colony,data=bees) 

#only models 4 7 8 and 11 converged. test AIC for them
AIC (amfCmodel4,amfCmodel7,amfCmodel8,amfCmodel11)
# model 4 wins

summary(amfCmodel4)
# model 4 wins: 
# when I compare AMF+/AMF- / control, only colony matters

anova(amfCmodel4, amfCmodel2)
# ### high vs low fertilizer

#read in df without control
fasurv <- read.csv(file="fert.amf.surv.csv", na.strings='', header=T)
str(fasurv)
fasurv <- fasurv[1:141,]


### turn bee size and consumption into z-scores

fasurv$pol.cons.scaled <- scale (fasurv$pol.cons, center=TRUE, scale=TRUE)
fasurv$nec.cons.scaled <- scale (fasurv$nec.cons, center=TRUE, scale=TRUE)


#  'diet' refers to tobacco vs control diet
# 'treat' is specific diet treatment (AH, NH, AL, NL, Control)
# 'fert' is H/L fert diet treatment (excludes control)
# 'amf" is y/n AMF diet treatment (excludes control)


# complete cases
fasurv <- fasurv[complete.cases(fasurv$pol.cons.scaled), ] 
fasurv <- fasurv[complete.cases(fasurv$nec.cons.scaled), ] 
fasurv = fasurv[fasurv$pol.cons > 0,]

# set up the response variable for high vs low fertilizer
library(survival)
SF2 <-Surv(
  time=fasurv$days.to.death,
  event=fasurv$dead.before.dissect
)

# build the models for high vs low fertilizer
fertmodel1 <-coxph(SF2~hlfert,data=fasurv) #with just high or low fert
fertmodel2 <-coxph(SF2~hlfert+colony,data=fasurv) #fert+ colony
fertmodel3 <-coxph(SF2~hlfert+inoc.date,data=fasurv) #fert+ inoc. date
fertmodel4 <- coxph(SF2~colony+inoc.date,data=fasurv) #colony+inoc.date
fertmodel5 <- coxph(SF2~hlfert+colony+inoc.date,data=fasurv) # fert+ colony+ inoc.date
fertmodel6 <- coxph(SF2~colony,data=fasurv) # just colony
fertmodel7 <- coxph(SF2~inoc.date,data=fasurv)# just inoc.date


AIC (fertmodel1,fertmodel2,fertmodel3,fertmodel4,fertmodel5,fertmodel6,
     fertmodel7)

summary(fertmodel1)
summary(model5)
summary(model1)
# only colony matters when comparing high to low fertilizer


# set up the response variable for amf- vs amf+ 
library(survival)
SA <-Surv(
  time=fasurv$days.to.death,
  event=fasurv$dead.before.dissect
)



#build the model comparing AMF- to AMF+ 
amfmodel1 <- coxph(SA~ynamf,data=fasurv) #AMF+/AMF- and C
summary(amfmodel1)
amfmodel2 <- coxph(SA~ynamf+inoc.date,data=fasurv) #with inoc.date

amfmodel3 <- coxph(SA~ynamf+colony,data=fasurv) #with colony
amfmodel4 <- coxph(SA~colony+inoc.date,data=fasurv) #drop treatment
AIC(amfmodel1,amfmodel2,amfmodel3,amfmodel4)

summary(amfmodel1)
### nothing matters


survival <-Surv(fasurv$days.to.death, fasurv$dead.before.dissect)

# create Kaplan Meier object

survival.treatment <- survfit(survival~treat, data=fasurv)



# set up cox proportional hazards model
cox.full.m <- coxph(survival~hlfert*ynamf, data=fasurv)
summary(cox.full.m)


# let's compare tobacco diet to control diet
SD <-Surv(
  time=diet$days.to.death,
  event=diet$dead.before.dissect
)

diet <- read.csv(file="tobacco vs control diet.csv", na.strings='', header=T)
diet <- diet[1:201,]

tobmodel1 <- coxph(SD~diet,data=diet) #just comparing tob to control
tobmodel2 <- coxph(SD~diet+colony,data=diet) #diet+ colony
tobmodel3<- coxph(SD~diet+inoc.date,data=diet) # diet+ inoc.date
tobmodel4 <- coxph(SD~diet+inoc.date+colony,data=diet) #diet+colony+inoc.date
tobmodelglobal <- coxph(SD~diet*nec.cons+inoc.date+colony,data=diet) #diet+colony+inoc.date

AIC(tobmodel1,tobmodel2,tobmodel3,tobmodel4,tobmodelglobal)

summary(tobmodelglobal)
tobmodel2null <- coxph(SD~colony,data=diet) #diet+ colony
anova(tobmodel2, tobmodel2null, test="Chisq")
# no effect of diet; only colony matters
